<?php
/**
 * Hotel_Customizer Class
 * Makes adjustments to Storefront cores Customizer implementation.
 *
 * @author   WooThemes
 * @package  Hotel
 * @since    1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Hotel_Customizer' ) ) {
	/**
	 * The Hotel Customizer class
	 */
	class Hotel_Customizer {

		/**
		 * Setup class.
		 *
		 * @since 1.0
		 */
		public function __construct() {
			global $storefront_version;

			add_action( 'wp_enqueue_scripts', array( $this, 'add_customizer_css' ),               999 );
			add_action( 'customize_register', array( $this, 'edit_default_controls' ),            99 );
			add_filter( 'storefront_setting_default_values', array( $this, 'get_hotel_defaults' ) );

			/**
			 * The following can be removed when Storefront 2.1 lands
			 */
			add_action( 'customize_register', array( $this, 'edit_default_customizer_settings' ), 99 );
			add_action( 'init',               array( $this, 'default_theme_mod_values' ) );
			if ( version_compare( $storefront_version, '2.0.0', '<' ) ) {
				add_action( 'init',           array( $this, 'default_theme_settings' ) );
			}
		}

		/**
		 * Returns an array of the desired default Storefront options
		 *
		 * @return array
		 */
		public function get_hotel_defaults() {
			return apply_filters( 'hotel_default_settings', $args = array(
				'storefront_accent_color'                => '#5EC1A0',
				'storefront_header_background_color'     => '#1F2126',
				'storefront_header_link_color'           => '#5EC1A0',
				'storefront_header_text_color'           => '#93979f',
				'storefront_footer_background_color'     => '#1F2126',
				'storefront_footer_link_color'           => '#5EC1A0',
				'storefront_footer_heading_color'        => '#ffffff',
				'storefront_footer_text_color'           => '#93979f',
				'storefront_text_color'                  => '#A0A0A0',
				'storefront_heading_color'               => '#1F2126',
				'storefront_button_background_color'     => '#ffffff',
				'storefront_button_text_color'           => '#5EC1A0',
				'storefront_button_alt_background_color' => '#ffffff',
				'storefront_button_alt_text_color'       => '#1F2126',
				'storefront_layout'                      => 'left',
				'background_color'                       => 'F3F4F7',
			) );
		}

		/**
		 * Set default Customizer settings based on Hotel design.
		 *
		 * @param  array $wp_customize the Customizer object.
		 * @uses   get_hotel_defaults()
		 * @return void
		 */
		public function edit_default_customizer_settings( $wp_customize ) {
			foreach ( Hotel_Customizer::get_hotel_defaults() as $mod => $val ) {
				$wp_customize->get_setting( $mod )->default = $val;
			}
		}

		/**
		 * Returns a default theme_mod value if there is none set.
		 *
		 * @uses   get_hotel_defaults()
		 * @return void
		 */
		public function default_theme_mod_values() {
			foreach ( Hotel_Customizer::get_hotel_defaults() as $mod => $val ) {
				add_filter( 'theme_mod_' . $mod, function( $setting ) use ( $val ) {
					return $setting ? $setting : $val;
				});
			}
		}

		/**
		 * Sets default theme color filters for storefront color values.
		 * This function is required for Storefront < 2.0.0 support
		 *
		 * @uses   get_hotel_defaults()
		 * @return void
		 * @todo   remove when Storefront 2.1 is released.
		 */
		public function default_theme_settings() {
			$prefix_regex = '/^storefront_/';
			foreach ( self::get_hotel_defaults() as $mod => $val ) {
				if ( preg_match( $prefix_regex, $mod ) ) {
					$filter = preg_replace( $prefix_regex, 'storefront_default_', $mod );
					add_filter( $filter, function( $setting ) use ( $val ) {
						return $val;
					}, 99 );
				}
			}
		}

		/**
		 * Modify the default controls
		 *
		 * @param array $wp_customize the Customizer object.
		 * @return void
		 */
		public function edit_default_controls( $wp_customize ) {
			$wp_customize->get_setting( 'storefront_header_text_color' )->transport = 'refresh';
			$wp_customize->get_setting( 'storefront_header_background_color' )->transport = 'refresh';
		}

		/**
		 * Add CSS using settings obtained from the theme options.
		 *
		 * @return void
		 */
		public function add_customizer_css() {
			$accent_color                = get_theme_mod( 'storefront_accent_color' );
			$text_color                  = get_theme_mod( 'storefront_text_color' );
			$header_text_color           = get_theme_mod( 'storefront_header_text_color' );
			$header_link_color           = get_theme_mod( 'storefront_header_link_color' );
			$header_background_color     = get_theme_mod( 'storefront_header_background_color' );
			$button_text_color           = get_theme_mod( 'storefront_button_text_color' );
			$button_background_color     = get_theme_mod( 'storefront_button_background_color' );
			$button_alt_text_color       = get_theme_mod( 'storefront_button_alt_text_color' );
			$button_alt_background_color = get_theme_mod( 'storefront_button_alt_background_color' );

			$brighten_factor             = apply_filters( 'storefront_brighten_factor', 25 );
			$darken_factor               = apply_filters( 'storefront_darken_factor', -25 );

			list( $r, $g, $b )           = sscanf( $header_background_color, '#%02x%02x%02x' );

			// Active menu link color
			$luma                        = ( 0.2126 * $r + 0.7152 * $g + 0.0722 * $b ) / 255;

			// See: https://stackoverflow.com/a/12228906
			if ( $luma > .5 ) {
				$header_active_color = storefront_adjust_color_brightness( $header_link_color, -70 );
			} else {
				$header_active_color = storefront_adjust_color_brightness( $header_link_color, 70 );
			}

			$style = '
				.main-navigation ul li.smm-active li ul.products li.product h3 {
					color: ' . $header_text_color . ';
				}

				.site-header {
					box-shadow: 0 1px 3px rgba(' . $r . ', ' . $g . ', ' . $b . ', .2);
					background-color: ' . storefront_adjust_color_brightness( $header_background_color, -3 ) . ';
				}

				.smm-mega-menu {
					background-color: ' . $header_background_color . ';
				}

				.main-navigation ul li a:hover,
				.main-navigation ul li:hover > a,
				.site-title a:hover,
				a.cart-contents:hover,
				.site-header-cart .widget_shopping_cart a:hover,
				.site-header-cart:hover > li > a {
					color: ' . storefront_adjust_color_brightness( $header_link_color, $darken_factor ) . ';
				}

				.storefront-product-section .section-title:after,
				.widget h3.widget-title:after, .widget h2.widgettitle:after,
				.page-template-template-homepage-php .hentry .entry-header h1:after {
					background: ' . $accent_color . ';
				}

				table th {
					color: ' . storefront_adjust_color_brightness( $text_color, -50 ). ';
				}

				.onsale {
					background: ' . $accent_color . ';
					border-color: ' . $accent_color . ';
				}

				.single-product div.product .price,
				#wc-bookings-booking-form .wc-bookings-date-picker .ui-datepicker .ui-datepicker-title,
				#wc-bookings-booking-form .wc-bookings-booking-cost,
				ul.products li.product h3 {
					color: ' . storefront_adjust_color_brightness( $text_color, -60 ) . ';
				}

				button,
				input[type="button"],
				input[type="reset"],
				input[type="submit"],
				.button,
				.added_to_cart,
				.widget-area .widget a.button {
					background-color: ' . $button_background_color . ';
					color: ' . $button_text_color . ';
					box-shadow: inset 0 0 0 2px ' . $button_text_color . ';
				}

				button:hover,
				input[type="button"]:hover,
				input[type="reset"]:hover,
				input[type="submit"]:hover,
				.button:hover,
				.added_to_cart:hover,
				.widget-area .widget a.button:hover {
					background-color: ' . $button_text_color . ';
					color: ' . $button_background_color . ';
				}

				button.alt,
				input[type="button"].alt,
				input[type="reset"].alt,
				input[type="submit"].alt,
				.button.alt,
				.added_to_cart.alt {
					background-color: ' . $button_alt_background_color . ';
					color: ' . $button_alt_text_color . ';
					box-shadow: inset 0 0 0 2px ' . $button_alt_text_color . ';
				}

				button.alt:hover,
				input[type="button"].alt:hover,
				input[type="reset"].alt:hover,
				input[type="submit"].alt:hover,
				.button.alt:hover,
				.added_to_cart.alt:hover {
					background-color: ' . $button_alt_text_color . ';
					color: ' . $button_alt_background_color . ';
				}

				.pagination .page-numbers li .page-numbers.current,
				.woocommerce-pagination .page-numbers li .page-numbers.current {
					background-color: ' . $button_background_color . ';
					color: ' . $button_text_color . ';
				}

				@media screen and (min-width: 768px) {
					.widget-area,
					.storefront-product-section,
					.page-template-template-homepage-php .hentry {
						background: ' . $header_background_color . ';
					}

					.site-branding {
						background-color: ' . storefront_adjust_color_brightness( $header_background_color, 3 ) . ';
					}

					.main-navigation {
						background-color: ' . $header_background_color . ';
					}

					.main-navigation ul.menu li.current-menu-item > a,
					.main-navigation ul.nav-menu li.current-menu-item > a {
						color: ' . $header_active_color . ';
					}
				}
				';

			wp_add_inline_style( 'storefront-child-style', $style );
		}
	}
}

return new Hotel_Customizer();
