<?php
/**
 * Hotel_Integrations Class
 * Provides integrations with Storefront extensions by removing/changing incompatible controls/settings. Also adjusts default values
 * if they need to differ from the original setting.
 *
 * @author   WooThemes
 * @package  Hotel
 * @since    1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Hotel_Integrations' ) ) {
	/**
	 * The Hotel Integrations class
	 */
	class Hotel_Integrations {

		/**
		 * Setup class.
		 *
		 * @since 1.0
		 */
		public function __construct() {
			add_action( 'after_switch_theme', array( $this, 'edit_theme_mods' ) );
			add_action( 'customize_register', array( $this, 'edit_controls' ), 99 );

			/**
			 * Storefront WooCommerce Customiser
			 */
			if ( class_exists( 'Storefront_WooCommerce_Customiser' ) ) {
				add_filter( 'swc_setting_defaults', array( $this, 'hotel_swc_settings' ), 1000 );
			}
		}

		/**
		 * Define the desired Storefront WooCommerce Customiser setting defaults that will provide compatibility with this themes design.
		 *
		 * @return array The desired defaults.
		 */
		public function hotel_swc_defaults() {
			return array(
				'swc_product_columns'						=> '1',
				'swc_products_per_page'						=> '6',
				'swc_homepage_category_columns'				=> '1',
				'swc_homepage_category_limit'				=> '3',
				'swc_homepage_recent_products_columns'		=> '1',
				'swc_homepage_recent_products_limit'		=> '3',
				'swc_homepage_featured_products_columns'	=> '1',
				'swc_homepage_featured_products_limit'		=> '3',
				'swc_homepage_top_rated_products_columns'	=> '1',
				'swc_homepage_top_rated_products_limit'		=> '3',
				'swc_homepage_on_sale_products_columns'		=> '1',
				'swc_homepage_on_sale_products_limit'		=> '1',
				'swc_product_archive_add_to_cart'           => false,
			);
		}

		/**
		 * This function filters swc_setting_defaults.
		 * swc_setting_defaults is an array of default Storefront WooCommerce Customiser settings, defined in the extension.
		 * That array is checked, and the values are set for each setting, if a value doesn't already exist (IE on fresh install).
		 *
		 * This function filters that array to include the desired defaults for this theme.
		 *
		 * @param array $args The Storefront WooCommerce Customiser default args.
		 * @return array
		 */
		public function hotel_swc_settings( $args ) {
			$new_args = Hotel_Integrations::hotel_swc_defaults();

			return array_merge( $args, $new_args );
		}

		/**
		 * Remove unused/incompatible controls from the Customizer to avoid confusion
		 *
		 * @param array $wp_customize the Customizer object.
		 * @return void
		 */
		public function edit_controls( $wp_customize ) {
			/**
			 * Storefront Designer
			 */
			$wp_customize->remove_control( 'sd_header_layout' );
			$wp_customize->remove_control( 'sd_max_width' );
			$wp_customize->remove_control( 'sd_fixed_width' );
			$wp_customize->remove_control( 'sd_button_flat' );
			$wp_customize->remove_control( 'sd_button_shadows' );
			$wp_customize->remove_control( 'sd_button_background_style' );
			$wp_customize->remove_control( 'sd_button_rounded' );
			$wp_customize->remove_control( 'sd_button_size' );
			$wp_customize->remove_control( 'sd_header_layout_divider_after' );
			$wp_customize->remove_control( 'sd_button_divider_1' );
			$wp_customize->remove_control( 'sd_button_divider_2' );

			$wp_customize->remove_control( 'swc_header_search' );
			$wp_customize->remove_control( 'swc_header_cart' );
			$wp_customize->remove_control( 'swc_product_archive_description' );
			$wp_customize->remove_control( 'swc_shop_alignment' );
			$wp_customize->remove_control( 'swc_product_gallery_layout' );
			$wp_customize->remove_control( 'swc_product_archive_image' );

			/**
			 * Specify Storefront WooCommerce Customiser defaults based on bookshop_swc_defaults()
			 */
			if ( class_exists( 'Storefront_WooCommerce_Customiser' ) ) {
				foreach ( Hotel_Integrations::hotel_swc_defaults() as $mod => $val ) {
					$wp_customize->get_setting( $mod )->default = $val;
				}
			}
		}

		/**
		 * Remove any pre-existing theme mods for settings that are incompatible with Hotel.
		 *
		 * @return void
		 */
		public function edit_theme_mods() {
			/**
			 * Storefront Designer
			 */
			remove_theme_mod( 'sd_header_layout' );
			remove_theme_mod( 'sd_max_width' );
			remove_theme_mod( 'sd_fixed_width' );
			remove_theme_mod( 'sd_button_flat' );
			remove_theme_mod( 'sd_button_shadows' );
			remove_theme_mod( 'sd_button_background_style' );
			remove_theme_mod( 'sd_button_rounded' );
			remove_theme_mod( 'sd_button_size' );
			remove_theme_mod( 'sd_content_background_color' );

			/**
			 * Storefront WooCommerce Customiser
			 */
			remove_theme_mod( 'swc_header_search' );
			remove_theme_mod( 'swc_header_cart' );
			remove_theme_mod( 'swc_product_archive_description' );
			remove_theme_mod( 'swc_shop_alignment' );
			remove_theme_mod( 'swc_product_gallery_layout' );
			remove_theme_mod( 'swc_product_archive_image' );
		}
	}
}

return new Hotel_Integrations();
