<?php
/**
 * Hotel Class
 *
 * @author   WooThemes
 * @package  Hotel
 * @since    1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Hotel' ) ) {
	/**
	 * The main Hotel class
	 */
	class Hotel {
		/**
		 * Setup class.
		 *
		 * @since 1.0
		 */
		public function __construct() {
			$theme         = wp_get_theme( 'hotel' );
			$hotel_version = $theme['Version'];

			add_filter( 'body_class', array( $this, 'body_classes' ) );

			add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_styles' ) );

			add_filter( 'storefront_woocommerce_args', array( $this, 'woocommerce_support' ) );

			add_filter( 'storefront_recent_products_args', array( $this, 'homepage_products_args' ) );
			add_filter( 'storefront_custom_background_args', array( $this, 'hotel_background' ) );

			if ( defined( 'WC_VERSION' ) && version_compare( WC_VERSION, '3.3', '<' ) ) {
				add_filter( 'storefront_loop_columns', array( $this, 'loop_columns' ) );
			}
		}

		/**
		 * Adds custom classes to the array of body classes.
		 *
		 * @param array $classes Classes for the body element.
		 * @return array
		 */
		public function body_classes( $classes ) {
			global $storefront_version;

			if ( version_compare( $storefront_version, '2.3.0', '>=' ) ) {
				$classes[] = 'storefront-2-3';
			}

			return $classes;
		}

		/**
		 * Override Storefront default theme settings for WooCommerce.
		 * @return array the modified arguments
		 */
		public function woocommerce_support( $args ) {
			$args['single_image_width']              = 1240;
			$args['thumbnail_image_width']           = 622;
			$args['product_grid']['default_columns'] = 1;

			return $args;
		}

		/**
		 * Enqueue Storefront Styles
		 *
		 * @return void
		 */
		public function enqueue_styles() {
			global $storefront_version, $hotel_version;

			/**
			 * Styles
			 */
			wp_enqueue_style( 'storefront-style', get_template_directory_uri() . '/style.css', $storefront_version );
			wp_style_add_data( 'storefront-child-style', 'rtl', 'replace' );

			wp_enqueue_style( 'montserrat', '//fonts.googleapis.com/css?family=Montserrat:400,700', array( 'storefront-style' ) );
			wp_enqueue_style( 'karla', '//fonts.googleapis.com/css?family=Karla:400,400italic,700,700italic', array( 'storefront-style' ) );

			/**
			 * Javascript
			 */
			$suffix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';
			wp_enqueue_script( 'jquery-matchHeight', get_stylesheet_directory_uri() . '/assets/js/jquery-matchHeight.min.js', array( 'jquery' ), $hotel_version );
			wp_enqueue_script( 'jquery-sticky-kit', get_stylesheet_directory_uri() . '/assets/js/jquery.sticky-kit.min.js', array( 'jquery' ), $hotel_version );
			wp_enqueue_script( 'hotel', get_stylesheet_directory_uri() . '/assets/js/hotel' . $suffix . '.js', array( 'jquery' ), $hotel_version, false );

			if ( class_exists( 'WooCommerce' ) ) {
				if ( is_product() ) {
					wp_enqueue_script( 'hotel-gallery', get_stylesheet_directory_uri() . '/assets/js/gallery' . $suffix . '.js', array( 'jquery' ), $hotel_version, true );
				}
			}
		}

		/**
		 * Default layout orientation
		 *
		 * @return array args
		 * @param array $args homepage product args.
		 */
		public function homepage_products_args( $args ) {
			$args['columns'] = 1;
			$args['limit']   = 2;

			return apply_filters( 'hotel_homepage_products_args', $args );
		}

		/**
		 * Hotel default loop columns
		 *
		 * @param int $columns number of columns.
		 * @return array int
		 */
		public function loop_columns( $columns ) {
			return apply_filters( 'hotel_loop_columns', 1 );
		}

		/**
		 * The background arguments
		 *
		 * @param  array $args the background args.
		 * @return array $args the background args
		 */
		public function hotel_background( $args ) {
			$args['default-image']      = get_stylesheet_directory_uri() . '/assets/images/background.jpg';
			$args['default-repeat']     = 'no-repeat';
			$args['default-attachment'] = 'fixed';

			return $args;
		}
	}
}

return new Hotel();
